package com.ywt.alipaympapi.web.controller;

import com.ywt.alipaympapi.core.utils.ContextHelper;
import com.ywt.alipaympapi.core.utils.JsonSerializer;
import com.ywt.alipaympapi.models.BaseResponse;
import com.ywt.alipaympapi.models.BaseResponse2;
import com.ywt.alipaympapi.models.Constants;
import com.ywt.alipaympapi.models.auth.*;
import com.ywt.alipaympapi.core.exception.AppMessageException;
import com.ywt.alipaympapi.core.utils.CheckUtil;
import com.ywt.alipaympapi.core.utils.Checker;
import com.ywt.alipaympapi.models.enums.TerminalEnum;
import com.ywt.alipaympapi.service.AuthService;
import com.ywt.alipaympapi.web.interceptors.WebAppContext;
import com.ywt.gapi.gateway.AuthServiceGrpc;
import com.ywt.gapi.gateway.IssueJWTRequest;
import com.ywt.gapi.gateway.IssueJWTResponse;
import com.ywt.gapi.user.BindAlipayUserInfoRequest;
import com.ywt.gapi.user.BindAlipayUserInfoResponse;
import com.ywt.gapi.user.UserServiceGrpc;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;

/**
 * @author Walker
 * Created on 2022/8/29
 */
@Slf4j
@RestController("/auth")
@RequestMapping({"/auth"})
public class AuthController {

    @Autowired
    private UserServiceGrpc.UserServiceBlockingStub userServiceBlockingStub;
    @Autowired
    private AuthServiceGrpc.AuthServiceBlockingStub authServiceBlockingStub;
    @Autowired
    private AuthService authService;


    @RequestMapping(value = {"/bind"}, method = RequestMethod.POST)
    public @ResponseBody BaseResponse2<BindAlipayMpResp> bind(@RequestBody
                                                              BindAlipayMpReq reqData) {
        BaseResponse2<BindAlipayMpResp> baseResponse = new BaseResponse2<>();
        try {
            int terminal = ContextHelper.getCurrentTerminalWrapped();
            String ip = WebAppContext.current().getIP();
            String ticket = reqData.getTicket();
            String gwAppId = reqData.getGwAppId();
            CheckUtil.ensureNotEmpty(gwAppId, "gwAppId 不能为空");
            CheckUtil.ensureNotEmpty(ticket, "ticket 不能为空");
            AlipayMpCfg cfg = authService.getCfg(terminal);
            // 获取用户信息
            GetAlipayUserInfoReq req = new GetAlipayUserInfoReq();
            req.setTicket(ticket);
            req.setAppId(cfg.getAppId());
            req.setSaasSecurityKey(cfg.getSaasSecurityKey());
            GetAlipayUserInfoResp resp = authService.getAlipayUserInfo(req);
            String alipayUid = Checker.getStringValue(resp.getAlipayUid());
            CheckUtil.ensureNotEmpty(alipayUid, "支付宝用户信息有误，alipayUid 为空");
            String avatar = Checker.getStringValue(resp.getAvatar());
            String realName = Checker.getStringValue(resp.getRealName());
            String nickName = Checker.getStringValue(resp.getNickName());
            String mobile = Checker.getStringValue(resp.getMobile());
            CheckUtil.ensureNotEmpty(alipayUid, "支付宝用户未绑定手机，请先前往支付宝个人中心绑定");
            int age = Checker.getIntegerValue(resp.getAge());
            String idCardNo = Checker.getStringValue(resp.getIdCardNo());
            BindAlipayUserInfoResponse response = userServiceBlockingStub.bindAlipayUserInfo(BindAlipayUserInfoRequest.newBuilder()
                            .setAlipayUid(alipayUid)
                            .setAvatar(avatar)
                            .setRealName(realName)
                            .setNickName(nickName)
                            .setMobile(mobile)
                            .setIdCardNo(idCardNo)
                            .setAge(age)
                            .setTerminal(terminal)
                            .setIp(ip)
                    .build());
            if (response.getCode() == BaseResponse.SUCCEED) {
                int userId = response.getUserId();
                // 生成鉴权信息
                HashMap<String, Object> authData = new HashMap<>();
                authData.put("userId", userId);
                authData.put("alipayUid", alipayUid);
                IssueJWTRequest issueJWTRequest = IssueJWTRequest.newBuilder()
                        .setAppid(gwAppId)
                        .setAuthData(JsonSerializer.toJson(authData))
                        .setExpire(0)
                        .build();
                IssueJWTResponse issueJWTResponse = authServiceBlockingStub.issueJWT(issueJWTRequest);
                if (issueJWTResponse.getCode() != BaseResponse.SUCCEED) {
                    log.error("AuthController#bind(reqData={} ):授权失败：{}", reqData, issueJWTResponse.getMsg());
                    return baseResponse.failed(BaseResponse2.APP_ERROR, String.format("用户授权失败：%s", issueJWTResponse.getMsg()));
                }
                BindAlipayMpResp r = new BindAlipayMpResp();
                r.setUserId(userId);
                r.setToken(issueJWTResponse.getToken());
                r.setAlipayUid(alipayUid);
                r.setMobile(mobile);
                // 根据终端判断医院信息
                if (TerminalEnum.valueOf(terminal) == TerminalEnum.NFYYBYFY_ALIPAY_MP) {
                    r.setHospitalId(Constants.HOSPITAL_ID_NFYYBYFY);
                }
                return baseResponse.succeed(r);
            }
            return baseResponse.failed(BaseResponse.APP_ERROR, response.getInfo());
        } catch (AppMessageException appMessageException) {
            return baseResponse.error(appMessageException.getMessage());
        } catch (Exception e) {
            log.error("AuthController#bind(reqData = {}): {}", reqData, e.getMessage(), e);
            return baseResponse.error(e.getMessage());
        }
    }


}
