package com.ywt.alipaympapi.web.interceptors;

import com.fasterxml.jackson.databind.JsonNode;
import com.ywt.alipaympapi.core.utils.Checker;
import com.ywt.alipaympapi.core.utils.JsonSerializer;
import com.ywt.alipaympapi.core.utils.WebHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.UUID;

/**
 * 自定义拦截器
 * 从网关获取鉴权信息
 */
@Service("accessBehaviorInterceptor")
public class AccessBehaviorInterceptor implements HandlerInterceptor {
    private static final Logger logger = LoggerFactory.getLogger(AccessBehaviorInterceptor.class);

    @Override
    public boolean preHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o) {
        try {
            WebAppContext.current().init();
            WebAppContext.current().setRequestStartTime(System.currentTimeMillis());
            WebAppContext.current().setRequestID(UUID.randomUUID().toString());
            WebAppContext.current().setIP(WebHelper.getIP(httpServletRequest));

            String terminalStr = Checker.getStringValue(httpServletRequest.getHeader("pl-terminal"));
            WebAppContext.current().setTerminal(Checker.parseInt(terminalStr));

            String authData = httpServletRequest.getHeader("auth-data");
            String authData1 = httpServletRequest.getHeader("Auth-Data");
            String authData2 = httpServletRequest.getHeader("authdata");
            if (Checker.isNone(authData) && !Checker.isNone(authData1)) {
                authData = authData1;
            }
            if (!Checker.isNone(authData2)) {
                authData = authData2;
            }
            logger.info("authData: " + authData);
            if (!Checker.isNone(authData)) {
                try {
                    JsonNode jsonNode = JsonSerializer.readToNode(authData);
                    if (jsonNode != null && jsonNode.get("userId") != null) {
                        WebAppContext.current().setUserId(Checker.parseInt(jsonNode.get("userId").asText("0")));
                    }
                    if (jsonNode != null && jsonNode.get("alipayUid") != null) {
                        WebAppContext.current().setAlipayUid(Checker.getStringValue(jsonNode.get("alipayUid").asText("")));
                    }
                } catch (Exception e) {
                    logger.error("preHandle(authData): {}", e.getMessage(), e);
                    e.printStackTrace();
                }
            }
        } catch (Exception e) {
            logger.error("preHandle(): {}", e.getMessage(), e);
        }
        return true;
    }

    @Override
    public void postHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, ModelAndView modelAndView) throws Exception {

    }

    @Override
    public void afterCompletion(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, Exception e) throws Exception {
    }
}
